/*
 * Copyright 2011-2025 Mark Injerd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import com.android.build.gradle.internal.api.BaseVariantOutputImpl
import java.io.FileInputStream
import java.util.*

plugins {
	kotlin("android")
	alias(libs.plugins.android.application)
	alias(libs.plugins.compose)
	alias(libs.plugins.ksp)
}

val keystorePropertiesFile: File = rootProject.file("keystore.properties")
val keystoreProperties = Properties()
if (keystorePropertiesFile.exists()) {
	keystoreProperties.load(FileInputStream(keystorePropertiesFile))
}

val gitCommitHash by lazy {
	providers.exec {
		commandLine("git", "rev-parse", "--short", "HEAD")
	}.standardOutput.asText.get().trim()
}

android {
	namespace = "com.pilot51.voicenotify"
	compileSdk = 34
	defaultConfig {
		applicationId = "com.pilot51.voicenotify"
		minSdk = 21
		targetSdk = 34
		versionName = "1.4.3"
		versionCode = 33
		vectorDrawables.useSupportLibrary = true
		ksp {
			arg("room.schemaLocation", "$projectDir/schemas")
		}
	}

	buildFeatures {
		viewBinding = true
	}

	buildFeatures {
		buildConfig = true
		compose = true
	}

	compileOptions {
		sourceCompatibility = JavaVersion.VERSION_21
		targetCompatibility = JavaVersion.VERSION_21
		isCoreLibraryDesugaringEnabled = true
	}


	buildTypes {
		getByName("release") {
			@Suppress("UnstableApiUsage")
			postprocessing {
				isRemoveUnusedCode = true
				isOptimizeCode = true
				isShrinkResources = true
				isObfuscate = false
			}
			proguardFiles(
				getDefaultProguardFile("proguard-android-optimize.txt")
			)
		}
		getByName("debug") {
			applicationIdSuffix = ".debug"
		}
	}

	androidResources {
		@Suppress("UnstableApiUsage")
		generateLocaleConfig = true
	}

	applicationVariants.all {
		outputs.all {
			this as BaseVariantOutputImpl
			outputFileName = "VoiceNotify_v${defaultConfig.versionName}-${name}_$gitCommitHash.apk"
		}
	}
}

dependencies {
	coreLibraryDesugaring(libs.android.desugar)
	implementation(libs.accompanist.permissions)
	implementation(libs.androidx.activity.compose)
	implementation(libs.androidx.compose.material.iconsExtended)
	implementation(libs.androidx.compose.material3)
	implementation(libs.androidx.compose.ui.tooling)
	implementation(libs.androidx.core.ktx)
	implementation(libs.androidx.glance.appwidget)
	implementation(libs.androidx.navigation.compose)
	implementation(libs.androidx.preference)
	implementation(libs.androidx.room.ktx)
	implementation(libs.kotlin.reflect)
	implementation(libs.autostarter)
	ksp(libs.androidx.room.compiler)
}
